.. _cli:

=====
Usage
=====

.. click:: omi.cli:cli
   :prog: omi
   :show-nested:

A list of available dialects can be found in the :ref:`dialect segment<available_dialects>`

To use omi in a project::

	import omi
